==> trivianpm-1.4.0.tgz: package/readme.md <==
![ckarit](https://cdn.discordapp.com/attachments/843326059507089418/847530273276821504/trivianpm.png)

# Instalacion
```bash
npm i trivianpm@latest
```
# Ventajas
- Quiz rapido
- Pocos recursos desgastados
- Quiz customizable

# Ejemplo
```js
const Trivia = require('trivianpm')
const Discord = require('discord.js')
const client = new Discord.Client()
client.on('message', async message => {
  let prefix= "!"
  if(message.content.startsWith(prefix+"trivia")){
    const json = await Trivia.getTrivia()
    const embed = new Discord.MessageEmbed()
    .setTitle(json.question)
    .setImage(json.image)
    .setDescription(json.answers.join("\n"));
    message.channel.send(embed).then(msg => {
      message.channel.awaitMessages(filter, { max: 1, time: 60000})
        .then(collected => {
          if(collected.first().content === json.answer){
            embed.setDescription("Lo lograste")
            return msg.edit(embed)
          } else {
            embed.setDescription("Fallaste...")
            return msg.edit(embed)
          }
        })
        .catch(collected => {
          embed.setDescription("No escribiste nada.")
          msg.edit(embed)
        });
    })
  }
})
```
# Utilidades
Funcion | Descripcion 
--- | :---: 
***fiction*** | Obtener el json de una trivia de ficcion
***cultura*** | Obtener el json de una trivia de cultura
***famosos*** | Obtener el son de una trivia de famosos
***pais*** | Obtener el josn de una trivia de paises
____
# Version
#### Readme.MD en estado de beta

##### Trazka ©️

==> trivianpm-2.2.0.tgz: package/readme.md <==
![ckarit](https://cdn.discordapp.com/attachments/843326059507089418/847530273276821504/trivianpm.png)

# Instalacion
```bash
npm i trivianpm@latest
```
# Ventajas
- Quiz rapido
- Pocos recursos desgastados
- Quiz ficticio o real.

# Ejemplo
```js
const Trivia = require('trivianpm')
const Discord = require('discord.js')
const client = new Discord.Client()
client.on('message', async message => {
  let prefix= "!"
  if(message.content.startsWith(prefix+"trivia")){
    const json = await Trivia.fiction()
    const embed = new Discord.MessageEmbed()
    .setTitle(json.question)
    .setImage(json.image)
    .setDescription(json.answers.join("\n"));
    message.channel.send(embed).then(msg => {
      message.channel.awaitMessages(filter, { max: 1, time: 60000})
        .then(collected => {
          if(collected.first().content === json.answer){
            embed.setDescription("Lo lograste")
            return msg.edit(embed)
          } else {
            embed.setDescription("Fallaste...")
            return msg.edit(embed)
          }
        })
        .catch(collected => {
          embed.setDescription("No escribiste nada.")
          msg.edit(embed)
        });
    })
  }
})
```
# Utilidades
Funcion | Descripcion 
--- | :---: 
***fiction*** | Obtener el json de una trivia de ficcion
***cultura*** | Obtener el json de una trivia de cultura
***famosos*** | Obtener el son de una trivia de famosos
***pais*** | Obtener el josn de una trivia de paises
____
# Version
#### Readme.MD en estado de beta

##### Trazka ©️
